PyXMake Developer Guide: PyXMake.Plugin Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Namespaces | Functions
PyXMake.Plugin Namespace Reference

Imports additional features provided by and for 3rd party packages. More...

## Namespaces
namespace | __build
namespace | __git
namespace | __gitlab
namespace | __poetry

## Functions
| main ()
| Provide a custom error handler for the interruption event triggered by this wrapper to prevent multiple wheels from being created.

## Detailed Description

Imports additional features provided by and for 3rd party packages.

    Imports all utility features provided by and for 3rd party packages.

    @note: PyXMake plug-in manager
    Created on 22.08.2022

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  22.08.2022

Notes/Changes
  - Added documentation // mg 22.08.2022

## Function Documentation

## ◆ main()

PyXMake.Plugin.main | ( |  | ) |

Provide a custom error handler for the interruption event triggered by this wrapper to prevent multiple wheels from being created.

Only affects exit codes when using CI runners

Added option to increase the default recursion limit through an environment variable. The given default limit is never used in practice, but gives viewers an idea of the limit range.

    This is the main entry point. Acts as a compatibility shim for poetry.

Definition at line 62 of file __init__.py.